import React, { useEffect } from 'react';
import { Form, Button, Select, Input } from 'antd';
import { useForm } from 'antd/lib/form/Form';

export const renderButtonGroup = props => {
  const { buttons, wrapper = false } = props;
  const bts = buttons.map((bt, index) => {
    const { text, ...rest } = bt;
    return (
      <Button {...rest} key={index}>
        {text}
      </Button>
    );
  });
  if (wrapper) {
    const { Comp, props: wrapperProps } = wrapper;
    return <Comp {...wrapperProps}>{bts}</Comp>;
  }
  return bts;
};

export const BaseFormItem = itemOption => {
  const { formType, ...rest } = itemOption;
  switch (formType) {
    case 'input':
      // eslint-disable-next-line no-undef
      return <Input allowClear {...rest} />;
    case 'select':
      // eslint-disable-next-line no-undef
      return <Select {...rest} />;
    default:
      return null;
  }
};

/**
 * 基本表单
 * @param {*} props
 *  items: 每个表单项
 *  buttons： 表单按钮
 */
const BaseForm = props => {
  const {
    items,
    buttons = [],
    buttonGroupProps = {},
    getForm, // 用来获取表单实例
    formProps,
  } = props;

  const [form] = useForm();

  useEffect(() => {
    // 执行回调让外部组件拿到表单实例
    // eslint-disable-next-line no-unused-expressions
    getForm && getForm(form);
  }, []);

  return (
    <Form size="small" form={form} {...formProps}>
      {items &&
        items.map(item => {
          const {
            label,
            dataIndex,
            initialValue = '',
            rules = [],
            formItemProps = {},
            ...rest
          } = item;
          return (
            <Form.Item
              label={label}
              name={dataIndex}
              key={`formItem_${dataIndex}`}
              rules={rules}
              initialValue={initialValue}
              {...formItemProps}
            >
              <BaseFormItem {...rest} />
            </Form.Item>
          );
        })}
      {renderButtonGroup({
        buttons,
        wrapper: { Comp: Form.Item, props: buttonGroupProps },
      })}
    </Form>
  );
};

export default BaseForm;
