import React, { useState } from 'react';
import { Alert, notification } from 'antd';
import { login } from '@/services/user/api';
import { AUTHORITY, BASENAME, USER_MODE } from '@/utils/constants';
import { connect } from 'react-redux';
import { actionCreators } from '@/containers/App/store';
import LoginForm from './components/Login';
import styles from './style.less';
import { setAuthority } from '@/utils/authority';
import history from '@/utils/history';
const { UserName, Password, Submit } = LoginForm;

const LoginMessage = ({ content }) => (
  <Alert
    style={{
      marginBottom: 24,
    }}
    message={content}
    type="error"
    showIcon
  />
);

const Login = props => {
  const { userLogin = {}, submitting, setAuth } = props;
  const { status, type: loginType } = userLogin;
  // const [autoLogin, setAutoLogin] = useState(true);
  const [type, setType] = useState('account');
  const handleSubmit = values => {
    /* eslint-disable no-console */
    console.log(values); // eg:{userName: "123", password: "123"}
    const { userName: loginName, password } = values;
    login({ loginName, password }).then(result => {
      console.log(result);
      if (result.success === true && result.pass === true) {
        const { userMode } = result;
        localStorage.setItem('userMode', userMode);
        if (userMode === USER_MODE.ADMIN || userMode === USER_MODE.SUPER) {
          const authority = [AUTHORITY.LOGIN, AUTHORITY[userMode]];
          setAuthority(authority);
          setAuth(authority);
          history.push(`/${BASENAME}/dbm/dbInit/`);
        }
        if (userMode === USER_MODE.COMMON) {
          const authority = [AUTHORITY.LOGIN, AUTHORITY.COMMON];
          setAuthority(authority);
          setAuth(authority);
          history.push(`/${BASENAME}/ou/orgList/`);
        }
      } else {
        notification.warning({
          message: '没有权限！',
        });
      }
    });
  };

  return (
    <div className={styles.main}>
      <LoginForm activeKey={type} onTabChange={setType} onSubmit={handleSubmit}>
        {status === 'error' && loginType === 'account' && !submitting && (
          <LoginMessage content="账户或密码错误（admin/ant.design）" />
        )}
        <UserName
          name="userName"
          placeholder="请输入用户名"
          rules={[
            {
              required: true,
              message: '请输入用户名!',
            },
          ]}
        />
        <Password
          name="password"
          placeholder="请输入密码"
          rules={[
            {
              required: true,
              message: '请输入密码！',
            },
          ]}
        />
        <div>
          {/* <Checkbox
            checked={autoLogin}
            onChange={e => setAutoLogin(e.target.checked)}
          >
            自动登录
          </Checkbox> */}
          {/* <a
            style={{
              float: 'right',
            }}
          >
            忘记密码
          </a> */}
        </div>
        <Submit loading={submitting}>登录</Submit>
      </LoginForm>
    </div>
  );
};

const mapState = () => ({});
const mapDispatch = dispatch => ({
  setAuth: auth => dispatch(actionCreators.setAuth(auth)),
});
export default connect(
  mapState,
  mapDispatch,
)(Login);
