import { get, post } from '@/services/index';
import qs from 'qs';

export const getUserTree = (selectOU, node) =>
  get(`/Cityinterface/rest/services/OMS.svc/U_GetOUTree`, {
    _version: 9999,
    _dc: new Date().getTime(),
    selectOU,
    node,
  });

export const getOneOUUserListNew = OUID =>
  get(`/Cityinterface/rest/services/OMS.svc/U_GetOneOUUserListNew`, {
    _version: 9999,
    _dc: new Date().getTime(),
    OUID,
  });

/**
 * 查询用户
 * @param {*} key
 */
export const getUserByKey = key =>
  get(`/Cityinterface/rest/services/OMS.svc/U_GetUserByKey`, {
    _version: 9999,
    _dc: new Date().getTime(),
    key,
  });

/**
 * 添加用户
 * @param {*} param0
 */
export const addUser = ({
  OUID,
  loginName,
  userName,
  password,
  phone,
  email,
}) =>
  get(`/Cityinterface/rest/services/OMS.svc/U_AddUser`, {
    _version: 9999,
    _dc: Date.now(),
    OUID,
    loginName,
    userName,
    password,
    phone,
    email,
  });

export const submitAddOrg = (orgID, OUName, description, comment) =>
  get(`/Cityinterface/rest/services/OMS.svc/U_AddOU`, {
    _version: 9999,
    _dc: Date.now(),
    pid: orgID,
    OUName,
    description,
    comment,
  });

export const editOrgInfo = (orgID, OUName, description, comment) =>
  get(`/Cityinterface/rest/services/OMS.svc/U_EditOneOUInfo`, {
    _version: 9999,
    _dc: Date.now(),
    OUID: orgID,
    OUName,
    description,
    comment,
  });

export const deleteOrg = orgID =>
  get(`/Cityinterface/rest/services/OMS.svc/U_DeleteOU`, {
    _version: 9999,
    _dc: Date.now(),
    OUID: orgID,
  });

export const getUserRelationList = userID =>
  get(`/Cityinterface/rest/services/OMS.svc/W4_GetUserRelationList`, {
    _version: 9999,
    _dc: Date.now(),
    userID: `${userID}`,
  });

export const addToOrg = (userID, orgID, newOrgID) =>
  get(`/Cityinterface/rest/services/OMS.svc/U_JumpToAnotherOU`, {
    _version: 9999,
    _dc: Date.now(),
    userID,
    oldOUID: orgID,
    newOUID: newOrgID,
  });

export const updateUserPassword = (
  userID,
  oldpassword,
  newPassword,
  passwordConfirm,
) =>
  get(`/Cityinterface/rest/services/OMS.svc/U_UpdatePassword`, {
    _version: 9999,
    _dc: Date.now(),
    userID,
    oldpassword,
    newPassword,
    passwordConfirm,
  });

export const editUser = (userID, loginName, userName, phone, email) =>
  get(`/Cityinterface/rest/services/OMS.svc/U_EditUser`, {
    _version: 9999,
    _dc: Date.now(),
    userID,
    loginName,
    userName,
    phone,
    email,
  });

export const setUserState = (OUID, state) =>
  get(`/Cityinterface/rest/services/OMS.svc/U_UserStateOU`, {
    _version: 9999,
    _dc: Date.now(),
    OUID,
    state,
  });

export const deleteUser = userID =>
  get(`/Cityinterface/rest/services/OMS.svc/U_DeleteUser`, {
    _version: 9999,
    _dc: Date.now(),
    userID,
  });

export const setUserRelation = (userID, roleList = [], stationList) =>
  post(
    `/Cityinterface/rest/services/OMS.svc/U_SetUserRelationList?_version=9999`,
    qs.stringify({
      userID,
      roleList: roleList.length ? `${roleList.join(',')},` : '',
      stationList: stationList.length ? `${stationList.join(',')},` : '',
      headList: '',
      mobileMapList: '',
      currentSolution: '熊猫智慧水务平台',
    }),
    {
      headers: {
        'Content-Type': 'application/x-www-form-urlencoded',
      },
    },
  );
